@@ -737,3 +737,52 @@ test_that("Extinction open-population models", {
   rm(x)
 
 })
+
+
+################################################################################
+
+test_that("Extended post-simulation diagnosntic tests", {
+  skip_on_cran()
+
+  nw <- network.initialize(100, directed = FALSE)
+  nw <- set.vertex.attribute(nw, "risk", rep(1:5, each = 20))
+
+  est <- netest(nw,
+                formation = ~edges + nodefactor("risk"),
+                target.stats = c(50, 20, 20, 20, 20),
+                coef.diss = dissolution_coefs(~offset(edges), 25))
+
+  dx <- netdx(est, nsims = 2, nsteps = 10)
+  plot(dx)
+
+  param <- param.net(inf.prob = 0.5)
+  init <- init.net(i.num = 10)
+
+  control <- control.net(type = "SI", nsteps = 10, nsims = 2)
+  sim <- netsim(est, param, init, control)
+  plot(sim, type = "formation")
+
+  control <- control.net(type = "SI", nsteps = 10, nsims = 1)
+  sim <- netsim(est, param, init, control)
+  plot(sim, type = "formation")
+
+  est <- netest(nw,
+                formation = ~edges + concurrent,
+                target.stats = c(50, 20),
+                coef.diss = dissolution_coefs(~offset(edges), 25))
+
+  dx <- netdx(est, nsims = 5, nsteps = 100)
+  plot(dx)
+
+  param <- param.net(inf.prob = 0.5)
+  init <- init.net(i.num = 10)
+
+  control <- control.net(type = "SI", nsteps = 10, nsims = 2)
+  sim <- netsim(est, param, init, control)
+  plot(sim, type = "formation")
+
+  control <- control.net(type = "SI", nsteps = 10, nsims = 1)
+  sim <- netsim(est, param, init, control)
+  plot(sim, type = "formation")
+
+})
